@@ -165,7 +165,8 @@ cherokee_buffer_add_va_list (cherokee_buffer_t *buf, char *format, va_list args)
 	
 #if 1
 	if (estimated_length < len)
-		PRINT_ERROR ("  -> '%s' -> '%s', esti=%d real=%d\n", format, buf->buf, estimated_length, len);
+		PRINT_ERROR ("  -> '%s' -> '%s', esti=%d real=%d\n", 
+			     format, buf->buf + buf->len, estimated_length, len);
 #endif
 
 	if (len < 0) return ret_error;
@@ -468,7 +469,7 @@ cherokee_buffer_read_file (cherokee_buffer_t *buf, char *filename)
 	
 	/* Open the file
 	 */
-	f = open (filename, O_RDONLY);
+	f = open (filename, CHE_O_READ);
 	if (f < 0) return ret_error;
 
 	/* Read the content
@@ -507,7 +508,7 @@ cherokee_buffer_read_from_fd (cherokee_buffer_t *buf, int fd, size_t size, size_
 		case EIO:        return ret_error;
 		}
 
-		PRINT_ERROR ("ERROR: read(%d, %d,..) -> errno=%d '%s'\n", fd, size, errno, strerror(errno));
+		PRINT_ERROR ("ERROR: read(%d, %lu,..) -> errno=%d '%s'\n", fd, size, errno, strerror(errno));
 		return ret_error;
 	}
 	else if (len == 0) {
@@ -589,10 +590,10 @@ cherokee_buffer_add_version (cherokee_buffer_t *buf, int port, cherokee_version_
 
 	switch (ver) {
 	case ver_full_html:
-		cherokee_buffer_ensure_size (buf, buf->len + 29 + PACKAGE_VERSION_LEN + 6 + port_len + 10);
+		cherokee_buffer_ensure_size (buf, buf->len + 29 + sizeof(PACKAGE_VERSION) + 6 + port_len + 10);
 
 		cherokee_buffer_add (buf, "<address>Cherokee web server ", 29);
-		cherokee_buffer_add (buf, PACKAGE_VERSION, PACKAGE_VERSION_LEN);
+		cherokee_buffer_add_str (buf, PACKAGE_VERSION);
 		cherokee_buffer_add (buf, " Port ", 6);
 		cherokee_buffer_add (buf, port_str, port_len);
 		cherokee_buffer_add (buf, "</address>", 10);
@@ -699,8 +700,6 @@ cherokee_buffer_decode_base64 (cherokee_buffer_t *buf)
 }
 
 
-#ifndef CHEROKEE_EMBEDDED
-
 ret_t 
 cherokee_buffer_encode_base64 (cherokee_buffer_t *buf)
 {
@@ -772,7 +771,6 @@ cherokee_buffer_encode_base64 (cherokee_buffer_t *buf)
 	return ret_ok;
 }
 
-#endif 
 
 ret_t 
 cherokee_buffer_escape_html (cherokee_buffer_t *buf, cherokee_buffer_t **maybe_new)
