@@ -41,14 +41,14 @@
 # include <sys/types.h>
 #endif
 
-#ifdef HAVE_ARPA_INET_H
-# include <arpa/inet.h>
-#endif
-
 #ifdef HAVE_NETINET_IN_H
 # include <netinet/in.h>
 #endif
 
+#ifdef HAVE_ARPA_INET_H
+# include <arpa/inet.h>
+#endif
+
 #include "http.h"
 #include "list.h"
 #include "table.h"
@@ -143,8 +143,9 @@ struct cherokee_connection {
 
 	/* Authentication
 	 */
-	cherokee_buffer_t            *user;                /* alo    */
-	cherokee_buffer_t            *passwd;              /* secret */
+	cherokee_buffer_t             user;                /* alo    */
+	cherokee_buffer_t             passwd;              /* secret */
+	cherokee_buffer_t             nonce;               /* "nonce" for Digest */
 	cherokee_buffer_t            *realm_ref;           /* "My private data" */
 
 	cherokee_http_auth_t          auth_type;           /* Auth type of the resource */
