@@ -130,8 +130,10 @@ cherokee_connection_new  (cherokee_connection_t **cnt)
 	cherokee_buffer_new (&n->redirect);
 	cherokee_buffer_new (&n->host);
 	cherokee_buffer_new (&n->query_string);
-	cherokee_buffer_new (&n->user);
-	cherokee_buffer_new (&n->passwd);
+
+	cherokee_buffer_init (&n->user);
+	cherokee_buffer_init (&n->passwd);
+	cherokee_buffer_init (&n->nonce);
 
 	cherokee_buffer_init (&n->request_original);
 
@@ -177,8 +179,6 @@ cherokee_connection_free (cherokee_connection_t  *cnt)
 	cherokee_buffer_mrproper (&cnt->request_original);
 
 	cherokee_buffer_free (cnt->pathinfo);
-	cherokee_buffer_free (cnt->user);
-	cherokee_buffer_free (cnt->passwd);
 	cherokee_buffer_free (cnt->buffer);
 	cherokee_buffer_free (cnt->header_buffer);
 	cherokee_buffer_free (cnt->incoming_header);
@@ -191,6 +191,10 @@ cherokee_connection_free (cherokee_connection_t  *cnt)
 	cherokee_buffer_free (cnt->redirect);
 	cherokee_buffer_free (cnt->host);
 
+	cherokee_buffer_mrproper (&cnt->user);
+	cherokee_buffer_mrproper (&cnt->passwd);
+	cherokee_buffer_mrproper (&cnt->nonce);
+
 	if (cnt->arguments != NULL) {
 		cherokee_table_free2 (cnt->arguments, free);
 		cnt->arguments = NULL;
@@ -259,8 +263,6 @@ cherokee_connection_clean (cherokee_connection_t *cnt)
 	cherokee_buffer_mrproper (&cnt->request_original);
 
 	cherokee_buffer_clean (cnt->pathinfo);
-	cherokee_buffer_clean (cnt->user);
-	cherokee_buffer_clean (cnt->passwd);
 	cherokee_buffer_clean (cnt->local_directory);
 	cherokee_buffer_clean (cnt->web_directory);
 	cherokee_buffer_clean (cnt->effective_directory);
@@ -268,6 +270,10 @@ cherokee_connection_clean (cherokee_connection_t *cnt)
 	cherokee_buffer_clean (cnt->redirect);
 	cherokee_buffer_clean (cnt->host);
 	cherokee_buffer_clean (cnt->query_string);
+
+	cherokee_buffer_clean (&cnt->user);
+	cherokee_buffer_clean (&cnt->passwd);
+	cherokee_buffer_clean (&cnt->nonce);
 	
 	if (cnt->arguments != NULL) {
 		cherokee_table_free2 (cnt->arguments, free);
@@ -458,34 +464,22 @@ build_response_header__authenticate (cherokee_connection_t *cnt, cherokee_buffer
 	 * Eg: WWW-Authenticate: Digest realm="", qop="auth,auth-int", nonce="", opaque=""
 	 */
 	if (cnt->auth_type & http_auth_digest) {
-		int                i;
-		cherokee_buffer_t *nonce;
-		
+		/* Realm
+		 */
 		cherokee_buffer_ensure_size (buffer, 32 + cnt->realm_ref->len + 4);
 		cherokee_buffer_add (buffer, "WWW-Authenticate: Digest realm=\"", 32);
 		cherokee_buffer_add_buffer (buffer, cnt->realm_ref);
-		cherokee_buffer_add (buffer, "\", ", 3);
+		cherokee_buffer_add_str (buffer, "\", ");
 
-		/* Nonce: Randomized data, at least 64 bits
+		/* Nonce
 		 */
-		cherokee_buffer_new (&nonce);
-		cherokee_buffer_ensure_size (nonce, 16);
-		for (i=0; i<8; i++) {
-			long int rand;
-			char     tmp[2];
-
-			rand = random();
-			tmp[0] = rand & 0xFF;
-			tmp[1] = (rand >> 8) & 0xFF;
-			cherokee_buffer_add (nonce, tmp, 2);
-		}
-		cherokee_buffer_encode_hex (nonce);
-		cherokee_buffer_add_va (buffer, "nonce=\"%s\", ", nonce->buf);
-		cherokee_buffer_free (nonce);
-		
-		/* Qop: auth, auth-int, auth-conf
+		cherokee_nonce_table_generate (&CONN_VSRV(cnt)->nonces, cnt, &cnt->nonce);
+		cherokee_buffer_add_va (buffer, "nonce=\"%s\", ", cnt->nonce.buf);
+				
+		/* Quality of protection: auth, auth-int, auth-conf
+		 * Algorithm: MD5
 		 */
-		cherokee_buffer_add (buffer, "qop=\"auth\""CRLF, 12);
+		cherokee_buffer_add_str (buffer, "qop=\"auth\", algorithm=\"MD5\""CRLF);
 	}
 }
 
@@ -860,8 +854,9 @@ cherokee_connection_send (cherokee_connection_t *cnt)
 ret_t 
 cherokee_connection_pre_lingering_close (cherokee_connection_t *cnt)
 {
-	ret_t ret;
-
+	ret_t  ret;
+	size_t readed;
+	
 	/* At this point, we don't want to follow the TLS protocol
 	 * any longer.
 	 */
@@ -878,7 +873,7 @@ cherokee_connection_pre_lingering_close (cherokee_connection_t *cnt)
 
 	/* Read from the socket to nowhere
 	 */
-	ret = cherokee_socket_read (cnt->socket, NULL, DEFAULT_RECV_SIZE, NULL);
+	ret = cherokee_socket_read (cnt->socket, NULL, DEFAULT_RECV_SIZE, &readed);
 	switch (ret) {
 	case ret_eof:
 	case ret_error:
@@ -897,7 +892,7 @@ cherokee_connection_pre_lingering_close (cherokee_connection_t *cnt)
 ret_t
 cherokee_connection_step (cherokee_connection_t *cnt)
 {
-	ret_t ret = ret_ok;
+	ret_t step_ret = ret_ok;
 
 	return_if_fail (cnt->handler != NULL, ret_error);
 
@@ -909,41 +904,52 @@ cherokee_connection_step (cherokee_connection_t *cnt)
 
 	/* Do a step in the handler
 	 */
-	ret = cherokee_handler_step (cnt->handler, cnt->buffer);
-	switch (ret) {
+	step_ret = cherokee_handler_step (cnt->handler, cnt->buffer);
+	switch (step_ret) {
 	case ret_ok:
+	case ret_eof:
 	case ret_eof_have_data:
 		break;
 
-	case ret_eof:
 	case ret_error:
 	case ret_eagain:
 	case ret_ok_and_sent:
-		return ret;
+		return step_ret;
 
 	default:
-		RET_UNKNOWN(ret);
+		RET_UNKNOWN(step_ret);
 	}
 
 	/* May be encode..
 	 */
 	if (cnt->encoder != NULL) {
-		ret_t ret2;
+		ret_t              ret;
 		cherokee_buffer_t *tmp;
 
 		/* Encode
 		 */
-		ret2 = cherokee_encoder_encode (cnt->encoder, cnt->buffer, cnt->encoder_buffer);
-		if (ret2 < ret_ok) return ret2;
+		switch (step_ret) {
+		case ret_eof:
+		case ret_eof_have_data:
+			ret = cherokee_encoder_flush (cnt->encoder, cnt->buffer, cnt->encoder_buffer);			
+			step_ret = (cnt->encoder_buffer->len == 0)? ret_eof : ret_eof_have_data;
+			break;
+		default:
+			ret = cherokee_encoder_encode (cnt->encoder, cnt->buffer, cnt->encoder_buffer);
+			break;
+		}
+		if (ret < ret_ok) return ret;
 
 		/* Swap buffers	
 		 */
 		tmp = cnt->buffer;
 		cnt->buffer = cnt->encoder_buffer;
 		cnt->encoder_buffer = tmp;
+		
+		cherokee_buffer_clean (cnt->encoder_buffer);
 	}
 	
-	return ret;
+	return step_ret;
 }
 
 
@@ -993,7 +999,7 @@ get_encoding (cherokee_connection_t    *cnt,
 	char *ext;
 	ret_t ret;
 
-	/* ptr = Header at the "Accept-Encoding position 
+	/* ptr = Header at the "Accept-Encoding" position 
 	 */
 	end = strchr (ptr, '\r');
 	if (end == NULL) {
@@ -1055,8 +1061,8 @@ get_authorization (cherokee_connection_t *cnt,
 {
 	cherokee_buffer_t auth = CHEROKEE_BUF_INIT;
 
-	cherokee_buffer_clean (cnt->user);
-	cherokee_buffer_clean (cnt->passwd);
+	cherokee_buffer_clean (&cnt->user);
+	cherokee_buffer_clean (&cnt->passwd);
 
 	if (strncasecmp(ptr, "Basic ", 6) == 0) {
 		char *end;
@@ -1084,8 +1090,8 @@ get_authorization (cherokee_connection_t *cnt,
 			goto error;
 		}
 		
-		cherokee_buffer_add (cnt->user, auth.buf, end - auth.buf);
-		cherokee_buffer_add (cnt->passwd, end+1, auth.len  - (end - auth.buf));		
+		cherokee_buffer_add (&cnt->user, auth.buf, end - auth.buf);
+		cherokee_buffer_add (&cnt->passwd, end+1, auth.len  - (end - auth.buf));		
 
 	} else if (strncasecmp(ptr, "Digest ", 7) == 0) {
 
@@ -1262,7 +1268,6 @@ get_range (cherokee_connection_t *cnt, char *ptr, int ptr_len)
 static ret_t
 post_init (cherokee_connection_t *cnt)
 {
-	int   r;
 	ret_t ret;
 
 	if (cnt->post != NULL) {
@@ -1287,8 +1292,10 @@ post_init (cherokee_connection_t *cnt)
 
 	/* Read the number
 	 */
-	r = sscanf (cnt->post->buf, "%d", &cnt->post_len);
-	if (r <= 0) {
+	cnt->post_len = -1;
+	cnt->post_len = atol(cnt->post->buf);
+	if (cnt->post_len < 0) {
+		cnt->post_len = 0;
 		return ret_error;
 	}
 
@@ -1581,11 +1588,11 @@ cherokee_connection_check_authentication (cherokee_connection_t *cnt, cherokee_d
 	{
 		void *foo;
 
-		if (cherokee_buffer_is_empty (cnt->user)) {
+		if (cherokee_buffer_is_empty (&cnt->user)) {
 			goto unauthorized;			
 		}
 
-		ret = cherokee_table_get (plugin_entry->users, cnt->user->buf, &foo);
+		ret = cherokee_table_get (plugin_entry->users, cnt->user.buf, &foo);
 		if (ret != ret_ok) {
 			goto unauthorized;
 		}
