@@ -178,11 +178,11 @@ cherokee_connection_info_fill_up (cherokee_connection_info_t *info, cherokee_con
 
 		/* File size
 		 */
-		cherokee_buffer_add_va (&info->total_size, FMT_OFFSET, (CST_OFFSET)file->info.st_size);
+		cherokee_buffer_add_va (&info->total_size, FMT_OFFSET, (CST_OFFSET)file->info->st_size);
 		
 		/* Percent	
 		 */
-		percent = (CST_OFFSET)conn->tx * (double)100 / (CST_OFFSET)file->info.st_size;
+		percent = (CST_OFFSET)conn->tx * (double)100 / (CST_OFFSET)file->info->st_size;
 		cherokee_buffer_add_va (&info->percent, "%f", percent);
 		
 		point = strchr (info->percent.buf, '.');
