@@ -121,14 +121,7 @@ cherokee_handler_common_new (cherokee_handler_t **hdl, void *cnt, cherokee_table
 	/* Check some properties
 	 */
 	if (properties != NULL) {
-		ret_t  ret;
-		char  *tmp;
-
-		ret = cherokee_table_get (properties, "cache", (void **)&tmp);
-		if (ret == ret_ok) {
-			if (!strcmp(tmp, "off"))
-				use_iocache = false;
-		}
+		cherokee_typed_table_get_int (properties, "cache", &use_iocache);
 	}
 
 	/* Check the request
