@@ -29,10 +29,16 @@
 #include <sys/stat.h>
 #include <unistd.h>
 #include <dirent.h>
-#include <pwd.h>
-#include <grp.h>
 #include <sys/types.h>
 
+#ifdef HAVE_PWD_H
+#  include <pwd.h>
+#endif
+
+#ifdef HAVE_GRP_H
+#  include <grp.h>
+#endif
+
 #include "list.h"
 #include "list_merge_sort.h"
 #include "util.h"
@@ -186,32 +192,21 @@ cherokee_handler_dirlist_new  (cherokee_handler_t **hdl, void *cnt, cherokee_tab
 	/* Read the properties
 	 */
 	if (properties) {
-		char *tmp;
+		char *tmp = NULL;
 
-		tmp = cherokee_table_get_val (properties, "bgcolor");
-		if (tmp) n->bgcolor = tmp;
+		cherokee_typed_table_get_str (properties, "bgcolor", &n->bgcolor);
+		cherokee_typed_table_get_str (properties, "text", &n->text);
+		cherokee_typed_table_get_str (properties, "link", &n->link);
+		cherokee_typed_table_get_str (properties, "vlink", &n->vlink);
+		cherokee_typed_table_get_str (properties, "alink", &n->alink);
+		cherokee_typed_table_get_str (properties, "background", &n->background);
 
-		tmp = cherokee_table_get_val (properties, "text");
-		if (tmp) n->text = tmp;
+		cherokee_typed_table_get_int (properties, "size", &n->show_size);
+		cherokee_typed_table_get_int (properties, "date", &n->show_date);
+		cherokee_typed_table_get_int (properties, "owner", &n->show_owner);
+		cherokee_typed_table_get_int (properties, "group", &n->show_group);
 
-		tmp = cherokee_table_get_val (properties, "link");
-		if (tmp) n->link = tmp;
-
-		tmp = cherokee_table_get_val (properties, "vlink");
-		if (tmp) n->vlink = tmp;
-
-		tmp = cherokee_table_get_val (properties, "alink");
-		if (tmp) n->alink = tmp;
-
-		tmp = cherokee_table_get_val (properties, "background");
-		if (tmp) n->background = tmp;		
-
-		n->show_size  = (cherokee_table_get_val (properties, "size") != NULL);
-		n->show_date  = (cherokee_table_get_val (properties, "date") != NULL);
-		n->show_owner = (cherokee_table_get_val (properties, "owner") != NULL);
-		n->show_owner = (cherokee_table_get_val (properties, "group") != NULL);
-
-		tmp = cherokee_table_get_val (properties, "headerfile");
+		cherokee_typed_table_get_str (properties, "headerfile", &tmp);
 		if (tmp != NULL) {
 			cherokee_buffer_new (&n->header_file);
 			cherokee_buffer_add (n->header_file, tmp, strlen(tmp));
