@@ -71,10 +71,10 @@ typedef struct {
 	char *alink;       /* color for active hypertext links */
 	char *background;  /* URL for an image to be used to tile the background */
 
-	int show_size;
-	int show_date;
-	int show_owner;
-	int show_group;
+	cuint_t show_size;
+	cuint_t show_date;
+	cuint_t show_owner;
+	cuint_t show_group;
 	
 	cherokee_buffer_t *header;       /* Header content */
 	cherokee_buffer_t *header_file;  /* Header filename */
