@@ -80,14 +80,7 @@ cherokee_handler_file_new  (cherokee_handler_t **hdl, cherokee_connection_t *cnt
 	/* Check some properties
 	 */
 	if (properties != NULL) {
-		ret_t  ret;
-		char  *tmp;
-
-		ret = cherokee_table_get (properties, "cache", (void **)&tmp);
-		if (ret == ret_ok) {
-			if (!strcmp(tmp, "off"))
-				n->nocache = true;
-		}
+		cherokee_typed_table_get_int (properties, "cache", &n->nocache);
 	}
 
 	/* Return the object
@@ -391,7 +384,7 @@ cherokee_handler_file_init (cherokee_handler_file_t *n)
 		cherokee_mime_t *m;
 
 		ret = cherokee_mime_get_default (&m);
-		if (ret >= ret_ok) {
+		if (ret == ret_ok) {
 			ret = cherokee_mime_get (m, ext+1, &n->mime);
 		}
 	}
