@@ -82,8 +82,9 @@ cherokee_handler_phpcgi_new  (cherokee_handler_t **hdl, void *cnt, cherokee_tabl
 
 	/* Look for the interpreter in the properties
 	 */
-	if (properties)
-		interpreter = cherokee_table_get_val (properties, "interpreter");
+	if (properties) {
+		cherokee_typed_table_get_str (properties, "interpreter", &interpreter);
+	}
 
 	if (interpreter == NULL) 
 		interpreter = DEFAULT_PHP_EXECUTABLE;
