@@ -32,7 +32,14 @@
 #include "list_merge_sort.h"
 #include "server-protected.h"
 
-#include <sys/mman.h>
+#ifdef HAVE_SYS_MMAN_H
+# include <sys/mman.h>
+#endif
+
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
+
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <unistd.h>
@@ -43,6 +50,9 @@
 #define FRESHNESS_TIME 600
 #define CACHE_SIZE      10
 
+#ifndef O_BINARY
+# define O_BINARY 0
+#endif
 
 #ifdef MAP_FILE
 # define MAP_OPTIONS MAP_SHARED | MAP_FILE
@@ -259,7 +269,7 @@ iocache_entry_update_mmap (cherokee_iocache_entry_t *entry, char *filename, int
 	/* Maybe open
 	 */
 	if (fd < 0) {
-		fd = open (filename, O_RDONLY);
+		fd = open (filename, O_RDONLY|O_BINARY);
 		if (unlikely (fd < 0)) return ret_error;
 
 		do_close = true;
@@ -348,7 +358,7 @@ cherokee_iocache_clean_up (cherokee_iocache_t *iocache, cuint_t num)
 ret_t 
 cherokee_iocache_free (cherokee_iocache_t *iocache)
 {
-	cherokee_table_free2 (&iocache->files, (cherokee_table_free_item_t)iocache_entry_free);
+	cherokee_table_mrproper2 (&iocache->files, (cherokee_table_free_item_t)iocache_entry_free);
 
 	CHEROKEE_MUTEX_DESTROY (&iocache->files_lock);
 
@@ -358,12 +368,13 @@ cherokee_iocache_free (cherokee_iocache_t *iocache)
 
 
 ret_t 
-cherokee_iocache_clean (cherokee_iocache_t *iocache)
+cherokee_iocache_free_default (cherokee_iocache_t *iocache)
 {
-	cherokee_table_clean2 (&iocache->files, (cherokee_table_free_item_t)iocache_entry_free);
-	iocache->files_num = 0;
+	if (iocache == __global) {
+		__global = NULL;
+	}
 
-	return ret_ok;
+	return cherokee_iocache_free (iocache);	
 }
 
 
