@@ -33,8 +33,10 @@
 #include <sys/types.h>
 #include <unistd.h>
 #include <fcntl.h>
-#include <syslog.h>
 
+#ifdef HAVE_SYSLOG_H
+# include <syslog.h>
+#endif
 
 #ifdef HAVE_SYS_TIME_H
 #include <sys/time.h>
@@ -106,8 +108,8 @@ cherokee_logger_ncsa_init_base (cherokee_logger_ncsa_t *logger, cherokee_table_t
 	logger->combined           = false;
 	
 	if (properties != NULL) {
-		logger->accesslog_filename = cherokee_table_get_val (properties, "AccessLog");
-		logger->errorlog_filename  = cherokee_table_get_val (properties, "ErrorLog");
+		cherokee_typed_table_get_str (properties, "AccessLog", &logger->accesslog_filename);
+		cherokee_typed_table_get_str (properties, "ErrorLog", &logger->errorlog_filename);
 	}
 	
 	return ret_ok;
@@ -129,15 +131,18 @@ open_output (cherokee_logger_ncsa_t *logger)
 		PRINT_ERROR("cherokee_logger_ncsa: error opening %s for append\n", logger->accesslog_filename); 
 		return ret_error;
 	}
+#ifndef _WIN32
 	fcntl (fileno (logger->accesslog_fd), F_SETFD, 1);
-	
+#endif	
 
         logger->errorlog_fd  = fopen (logger->errorlog_filename, "a+");
 	if (logger->errorlog_fd == NULL) {
 		PRINT_ERROR("cherokee_logger_ncsa: error opening %s for append\n", logger->errorlog_filename); 
 		return ret_error;
 	}
+#ifndef _WIN32
 	fcntl (fileno (logger->errorlog_fd), F_SETFD, 1);
+#endif
 
 	return ret_ok;
 }
@@ -146,7 +151,8 @@ open_output (cherokee_logger_ncsa_t *logger)
 static ret_t
 close_output (cherokee_logger_ncsa_t *logger)
 {
-	int ret, n = 2;
+	int n   = 2;
+	int ret = 0;
 
 	if (logger->errorlog_fd != NULL) {
 		ret = fclose (logger->errorlog_fd);
@@ -240,8 +246,8 @@ build_log_string (cherokee_logger_ncsa_t *logger, cherokee_connection_t *cnt, ch
 
 	/* Look for the user
 	 */
-	if (!cherokee_buffer_is_empty (cnt->user)) {
-		username = cnt->user->buf;
+	if (!cherokee_buffer_is_empty (&cnt->user)) {
+		username = cnt->user.buf;
 	} else {
 		username = "-";
 	}
