@@ -42,7 +42,7 @@ cherokee_module_get_name (cherokee_module_t *module, const char **name)
 {
 	/* Sanity check
 	 */
-	return_if_fail (module != NULL, ret_error);
+	if (module == NULL) return;
 
 	if (module->get_name != NULL) {
 		return module->get_name (module, name);
