@@ -23,16 +23,19 @@
  */
 
 #include "common-internal.h"
-
 #include "module_loader.h"
-#include "module_loader-protected.h"
-
-#include "table.h"
-#include "buffer.h"
 
 #include <stdlib.h>
 #include <string.h>
-#include <dlfcn.h>
+
+#ifndef CHEROKEE_EMBEDDED
+# ifdef HAVE_DLFCN_H
+#  include <dlfcn.h>
+# endif
+#endif
+
+#include "table.h"
+#include "buffer.h"
 
 
 typedef struct {
@@ -44,14 +47,13 @@ typedef struct {
 #ifdef CHEROKEE_EMBEDDED
 
 ret_t
-cherokee_module_loader_new  (cherokee_module_loader_t **loader)
+cherokee_module_loader_init  (cherokee_module_loader_t *loader)
 {
-	*loader = NULL;
 	return ret_ok;
 }
 
 ret_t 
-cherokee_module_loader_free (cherokee_module_loader_t *loader)
+cherokee_module_loader_mrproper (cherokee_module_loader_t *loader)
 {  
 	return ret_ok; 
 }
@@ -134,7 +136,7 @@ add_static_entry (cherokee_module_loader_t *loader, const char *name, void *info
 	entry->dlopen_ref = dlopen (NULL, RTLD_BASE);
 	entry->info       = info; 
 
-	cherokee_table_add (loader->table, (char *)name, entry);
+	cherokee_table_add (loader, (char *)name, entry);
 }
 
 
@@ -150,31 +152,39 @@ load_static_linked_modules (cherokee_module_loader_t *loader)
 	return ret_ok;
 }
 
+static void
+free_entry (void *item)
+{
+	entry_t *entry = (entry_t *)item;
+
+	if (entry->dlopen_ref) {
+		dlclose (entry->dlopen_ref);
+		entry->dlopen_ref = NULL;
+	}
+
+	free (item);
+}
+
 
 ret_t
-cherokee_module_loader_new  (cherokee_module_loader_t **loader)
+cherokee_module_loader_init (cherokee_module_loader_t *loader)
 {
 	ret_t ret;
 	
-	CHEROKEE_NEW_STRUCT (n, module_loader);
-	
-	ret = cherokee_table_new(&n->table);
+	ret = cherokee_table_init (TABLE(loader));
 	if (unlikely(ret < ret_ok)) return ret;
 	
-	ret = load_static_linked_modules (n);
+	ret = load_static_linked_modules (loader);
 	if (unlikely(ret < ret_ok)) return ret;
 
-	*loader = n;
 	return ret_ok;
 }
 
 
 ret_t 
-cherokee_module_loader_free (cherokee_module_loader_t *loader)
+cherokee_module_loader_mrproper (cherokee_module_loader_t *loader)
 {
-	cherokee_table_free2 (loader->table, (cherokee_table_free_item_t)free);
-
-	free (loader);
+	cherokee_table_mrproper2 (loader, (cherokee_table_free_item_t)free_entry);
 	return ret_ok;
 }
 
@@ -183,12 +193,14 @@ static void *
 get_sym_from_dlopen_handler (void *dl_handle, const char *sym)
 {
 	void *re;
+	char *error;
 	   
-	/* Look for the symbol
+	/* Clear the possible error and look for the symbol
 	 */
+	dlerror();
 	re = (void *) dlsym(dl_handle, sym);
-	if (re == NULL) {
-		PRINT_ERROR ("ERROR: %s\n", dlerror());
+	if ((error = dlerror()) != NULL)  {
+		PRINT_MSG ("ERROR: %s\n", dlerror());
 		return NULL;
 	}
 	
@@ -352,7 +364,7 @@ load_common (cherokee_module_loader_t *loader, char *modname, int flags)
 
 	/* If it is already loaded just return 
 	 */
-	ret = cherokee_table_get (loader->table, modname, (void **)&entry);
+	ret = cherokee_table_get (loader, modname, (void **)&entry);
 	if (ret == ret_ok) return ret_ok;
 	
 	/* Check deps
@@ -383,7 +395,7 @@ load_common (cherokee_module_loader_t *loader, char *modname, int flags)
 	entry->dlopen_ref = dl_handle;
 	entry->info       = info; 
 	
-	ret = cherokee_table_add (loader->table, modname, entry);
+	ret = cherokee_table_add (loader, modname, entry);
 	if (unlikely(ret != ret_ok)) return ret;
 
 	/* Execute init function
@@ -421,13 +433,14 @@ cherokee_module_loader_unload (cherokee_module_loader_t *loader, char *modname)
 
 	/* Remove item from the table
 	 */
-	ret = cherokee_table_del (loader->table, modname, (void **)&entry);
+	ret = cherokee_table_del (loader, modname, (void **)&entry);
 	if (ret != ret_ok) return ret;
 
 	/* Free the resources
 	 */
-	if (entry->dlopen_ref != NULL)
+	if (entry->dlopen_ref != NULL) {
 		re = dlclose (entry->dlopen_ref);
+	}
 
 	free (entry);
 
@@ -441,7 +454,7 @@ cherokee_module_loader_get_info (cherokee_module_loader_t *loader, char *modname
 	ret_t    ret;
 	entry_t *entry;
 
-	ret = cherokee_table_get (loader->table, modname, (void **)&entry);
+	ret = cherokee_table_get (loader, modname, (void **)&entry);
 	if (ret != ret_ok) return ret;
 
 	*info = entry->info;
@@ -458,7 +471,7 @@ cherokee_module_loader_get_sym  (cherokee_module_loader_t *loader, char *modname
 
 	/* Get the symbol from a dynamic library
 	 */
-	ret = cherokee_table_get (loader->table, modname, (void **)&entry);
+	ret = cherokee_table_get (loader, modname, (void **)&entry);
 	if (ret != ret_ok) return ret;
 
 	if (entry->dlopen_ref == NULL) 
