@@ -1,4 +1,4 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 2.0.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
    Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
@@ -48,60 +48,50 @@
      T_POLICY = 274,
      T_SERVER = 275,
      T_USERDIR = 276,
-     T_URL = 277,
-     T_PIDFILE = 278,
-     T_LISTEN = 279,
-     T_FILEDIR = 280,
-     T_SERVER_TOKENS = 281,
-     T_ENCODER = 282,
-     T_ALLOW = 283,
-     T_IO_CACHE = 284,
-     T_BGCOLOR = 285,
-     T_TEXT = 286,
-     T_LINK = 287,
-     T_ALINK = 288,
-     T_VLINK = 289,
-     T_BACKGROUND = 290,
-     T_DIRECTORYINDEX = 291,
-     T_IPV6 = 292,
-     T_SHOW = 293,
-     T_CHROOT = 294,
-     T_HEADER_FILE = 295,
-     T_ICONS = 296,
-     T_AUTH = 297,
-     T_NAME = 298,
-     T_METHOD = 299,
-     T_PASSWDFILE = 300,
-     T_SSL_CA_LIST_FILE = 301,
-     T_FROM = 302,
-     T_SOCKET = 303,
-     T_LOG_FLUSH_INTERVAL = 304,
-     T_INCLUDE = 305,
-     T_PANIC_ACTION = 306,
-     T_JUST_ABOUT = 307,
-     T_LISTEN_QUEUE_SIZE = 308,
-     T_SENDFILE = 309,
-     T_MINSIZE = 310,
-     T_MAXSIZE = 311,
-     T_MAX_FDS = 312,
-     T_INTERPRETER = 313,
-     T_SCRIPT_ALIAS = 314,
-     T_ONLY_SECURE = 315,
-     T_MAX_CONNECTION_REUSE = 316,
-     T_REWRITE = 317,
-     T_POLL_METHOD = 318,
-     T_EXTENSION = 319,
-     T_NUMBER = 320,
-     T_PORT = 321,
-     T_QSTRING = 322,
-     T_FULLDIR = 323,
-     T_ID = 324,
-     T_HTTP_URL = 325,
-     T_HTTPS_URL = 326,
-     T_HOSTNAME = 327,
-     T_IP = 328,
-     T_DOMAIN_NAME = 329,
-     T_ADDRESS_PORT = 330
+     T_PIDFILE = 277,
+     T_LISTEN = 278,
+     T_SERVER_TOKENS = 279,
+     T_ENCODER = 280,
+     T_ALLOW = 281,
+     T_IO_CACHE = 282,
+     T_DIRECTORYINDEX = 283,
+     T_ICONS = 284,
+     T_AUTH = 285,
+     T_NAME = 286,
+     T_METHOD = 287,
+     T_PASSWDFILE = 288,
+     T_SSL_CA_LIST_FILE = 289,
+     T_FROM = 290,
+     T_SOCKET = 291,
+     T_LOG_FLUSH_INTERVAL = 292,
+     T_INCLUDE = 293,
+     T_PANIC_ACTION = 294,
+     T_JUST_ABOUT = 295,
+     T_LISTEN_QUEUE_SIZE = 296,
+     T_SENDFILE = 297,
+     T_MINSIZE = 298,
+     T_MAXSIZE = 299,
+     T_MAX_FDS = 300,
+     T_SHOW = 301,
+     T_CHROOT = 302,
+     T_ONLY_SECURE = 303,
+     T_MAX_CONNECTION_REUSE = 304,
+     T_REWRITE = 305,
+     T_POLL_METHOD = 306,
+     T_EXTENSION = 307,
+     T_IPV6 = 308,
+     T_ENV = 309,
+     T_NUMBER = 310,
+     T_PORT = 311,
+     T_QSTRING = 312,
+     T_FULLDIR = 313,
+     T_ID = 314,
+     T_HTTP_URL = 315,
+     T_HTTPS_URL = 316,
+     T_HOSTNAME = 317,
+     T_IP = 318,
+     T_DOMAIN_NAME = 319,
+     T_ADDRESS_PORT = 320
    };
 #endif
 #define T_QUOTE 258
@@ -123,60 +113,50 @@
 #define T_POLICY 274
 #define T_SERVER 275
 #define T_USERDIR 276
-#define T_URL 277
-#define T_PIDFILE 278
-#define T_LISTEN 279
-#define T_FILEDIR 280
-#define T_SERVER_TOKENS 281
-#define T_ENCODER 282
-#define T_ALLOW 283
-#define T_IO_CACHE 284
-#define T_BGCOLOR 285
-#define T_TEXT 286
-#define T_LINK 287
-#define T_ALINK 288
-#define T_VLINK 289
-#define T_BACKGROUND 290
-#define T_DIRECTORYINDEX 291
-#define T_IPV6 292
-#define T_SHOW 293
-#define T_CHROOT 294
-#define T_HEADER_FILE 295
-#define T_ICONS 296
-#define T_AUTH 297
-#define T_NAME 298
-#define T_METHOD 299
-#define T_PASSWDFILE 300
-#define T_SSL_CA_LIST_FILE 301
-#define T_FROM 302
-#define T_SOCKET 303
-#define T_LOG_FLUSH_INTERVAL 304
-#define T_INCLUDE 305
-#define T_PANIC_ACTION 306
-#define T_JUST_ABOUT 307
-#define T_LISTEN_QUEUE_SIZE 308
-#define T_SENDFILE 309
-#define T_MINSIZE 310
-#define T_MAXSIZE 311
-#define T_MAX_FDS 312
-#define T_INTERPRETER 313
-#define T_SCRIPT_ALIAS 314
-#define T_ONLY_SECURE 315
-#define T_MAX_CONNECTION_REUSE 316
-#define T_REWRITE 317
-#define T_POLL_METHOD 318
-#define T_EXTENSION 319
-#define T_NUMBER 320
-#define T_PORT 321
-#define T_QSTRING 322
-#define T_FULLDIR 323
-#define T_ID 324
-#define T_HTTP_URL 325
-#define T_HTTPS_URL 326
-#define T_HOSTNAME 327
-#define T_IP 328
-#define T_DOMAIN_NAME 329
-#define T_ADDRESS_PORT 330
+#define T_PIDFILE 277
+#define T_LISTEN 278
+#define T_SERVER_TOKENS 279
+#define T_ENCODER 280
+#define T_ALLOW 281
+#define T_IO_CACHE 282
+#define T_DIRECTORYINDEX 283
+#define T_ICONS 284
+#define T_AUTH 285
+#define T_NAME 286
+#define T_METHOD 287
+#define T_PASSWDFILE 288
+#define T_SSL_CA_LIST_FILE 289
+#define T_FROM 290
+#define T_SOCKET 291
+#define T_LOG_FLUSH_INTERVAL 292
+#define T_INCLUDE 293
+#define T_PANIC_ACTION 294
+#define T_JUST_ABOUT 295
+#define T_LISTEN_QUEUE_SIZE 296
+#define T_SENDFILE 297
+#define T_MINSIZE 298
+#define T_MAXSIZE 299
+#define T_MAX_FDS 300
+#define T_SHOW 301
+#define T_CHROOT 302
+#define T_ONLY_SECURE 303
+#define T_MAX_CONNECTION_REUSE 304
+#define T_REWRITE 305
+#define T_POLL_METHOD 306
+#define T_EXTENSION 307
+#define T_IPV6 308
+#define T_ENV 309
+#define T_NUMBER 310
+#define T_PORT 311
+#define T_QSTRING 312
+#define T_FULLDIR 313
+#define T_ID 314
+#define T_HTTP_URL 315
+#define T_HTTPS_URL 316
+#define T_HOSTNAME 317
+#define T_IP 318
+#define T_DOMAIN_NAME 319
+#define T_ADDRESS_PORT 320
 
 
 
@@ -195,7 +175,7 @@ typedef union YYSTYPE {
 
 	   void *list;
 } YYSTYPE;
-/* Line 1285 of yacc.c.  */
+/* Line 1318 of yacc.c.  */
 
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
