@@ -57,18 +57,19 @@
 struct cherokee_server {
 	/* Current time
 	 */
-	time_t             start_time;
-	time_t             bogo_now;
-	struct tm          bogo_now_tm;
-	cherokee_buffer_t *bogo_now_string;
+	time_t                       start_time;
+	time_t                       bogo_now;
+	struct tm                    bogo_now_tm;
+	cherokee_buffer_t           *bogo_now_string;
 #ifdef HAVE_PTHREAD
-	pthread_rwlock_t   bogo_now_mutex;
+	pthread_rwlock_t             bogo_now_mutex;
 #endif
 
 	/* Exit related
 	 */
-	char                      *panic_action;
-	int                        wanna_exit;
+	char                        *panic_action;
+	cherokee_boolean_t           wanna_exit;
+	cherokee_server_reinit_cb_t  reinit_callback;
 	
 	/* Virtual servers
 	 */
@@ -86,7 +87,7 @@ struct cherokee_server {
 	/* Modules
 	 */
 	cherokee_logger_table_t   *loggers;
-	cherokee_module_loader_t  *loader;
+	cherokee_module_loader_t   loader;
 	cherokee_encoder_table_t  *encoders;
 
 	/* Tables: icons, iocache
