@@ -28,8 +28,14 @@
 #include <fcntl.h>
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <pwd.h>
-#include <grp.h>
+
+#ifdef HAVE_PWD_H
+# include <pwd.h>
+#endif
+
+#ifdef HAVE_GRP_H
+# include <grp.h>
+#endif
 
 #ifdef HAVE_SYS_SOCKET_H
 # include <sys/socket.h>
@@ -112,8 +118,9 @@ cherokee_server_new  (cherokee_server_t **srv)
 
 	/* Exit related
 	 */
-	n->wanna_exit      = 0;
+	n->wanna_exit      = false;
 	n->panic_action    = NULL;
+	n->reinit_callback = NULL;
 	
 	/* Server config
 	 */
@@ -197,10 +204,7 @@ cherokee_server_new  (cherokee_server_t **srv)
 
 	/* Module loader
 	 */
-	cherokee_module_loader_new (&n->loader);
-#ifndef CHEROKEE_EMBEDDED
-	return_if_fail (n->loader != NULL, ret_nomem);	
-#endif
+	cherokee_module_loader_init (&n->loader);
 
 	/* Virtual servers table
 	 */
@@ -244,7 +248,7 @@ cherokee_server_new  (cherokee_server_t **srv)
 }
 
 
-static inline void
+static void
 close_all_connections (cherokee_server_t *srv)
 {
 	list_t *i;
@@ -269,115 +273,11 @@ free_virtual_servers (cherokee_server_t *srv)
 }
 
 
-ret_t 
-cherokee_server_clean (cherokee_server_t *srv)
-{
-	/* Close all active connections
-	 */
-	close_all_connections (srv);
-
-	/* Clean the configuration
-	 */
-	if (srv->listen_to != NULL) {
-		free (srv->listen_to);
-		srv->listen_to = NULL;
-	}
-
-	if (srv->chroot != NULL) {
-		free (srv->chroot);
-		srv->chroot = NULL;
-	}
-
-
-	/* Clean config files entries
-	 */
-	cherokee_list_free (&srv->include_list, free);
-	
-	/* Exit related
-	 */
- 	srv->wanna_exit = 0;
-
-	if (srv->panic_action != NULL) {
-		free (srv->panic_action);
-		srv->panic_action = NULL;
-	}
-
-	/* Clean the loader
-	 */
-	cherokee_module_loader_free (srv->loader);
-	srv->loader = NULL;
-
-#ifndef CHEROKEE_EMBEDDED
-	/* Icons 
-	 */
-	cherokee_icons_clean (srv->icons);
-
-	if (srv->icons_file != NULL) {
-		free (srv->icons_file);
-		srv->icons_file = NULL;
-	}
-
-	/* IO cache cache
-	 */
-	cherokee_iocache_clean (srv->iocache);
-
-	/* Mime
-	 */
-	if (srv->mime_file != NULL) {
-		free (srv->mime_file);
-		srv->mime_file = NULL;
-	}
-
-	/* Regex cache
-	 */
-	cherokee_regex_table_clean (srv->regexs);
-#endif
-
-	/* Clean the encoders table
-	 */
-	cherokee_encoder_table_clean (srv->encoders);
-
-	/* Clean the loggers table
-	 */
-	cherokee_logger_table_clean (srv->loggers);
-
-	/* Clean the virtual servers table
-	 */
-	cherokee_virtual_server_clean (srv->vserver_default);
-
-	/* Clean the virtual servers table
-	 */	
-	free_virtual_servers (srv);
-	cherokee_table_clean (srv->vservers_ref);
-
-	/* Time-out pre-builded header
-	 */
-	cherokee_buffer_clean (srv->timeout_header);
-
-	/* Server string
-	 */
-	srv->server_token = cherokee_version_full;
-	cherokee_buffer_clean (srv->server_string);
-	
-	srv->system_fd_limit = -1;
-	srv->max_fds         = -1;
-	srv->max_conn_reuse  = -1;
-
-	srv->listen_queue  = 1024;
-	srv->sendfile.min  = 32768;
-	srv->sendfile.max  = 2147483647;
-
-	srv->keepalive_max = MAX_KEEPALIVE;
-
-	return ret_ok;
-}
-
-
 ret_t
 cherokee_server_free (cherokee_server_t *srv)
 {
 	close (srv->socket);
-
+	
 	if (srv->socket_tls != -1) {
 		close (srv->socket_tls);		
 	}
@@ -406,14 +306,11 @@ cherokee_server_free (cherokee_server_t *srv)
 		srv->mime_file = NULL;
 	}
 
-	cherokee_iocache_free (srv->iocache);
+	cherokee_iocache_free_default (srv->iocache);
+
 	cherokee_regex_table_free (srv->regexs);
 #endif
 	
-	/* Module loader
-	 */
-	cherokee_module_loader_free (srv->loader);
-
 	/* Virtual servers
 	 */
 	cherokee_virtual_server_free (srv->vserver_default);
@@ -451,6 +348,12 @@ cherokee_server_free (cherokee_server_t *srv)
 		srv->panic_action = NULL;
 	}
 
+	/* Module loader:
+	 * It must be the last action to perform because
+	 * it will close all the opened modules
+	 */
+	cherokee_module_loader_mrproper (&srv->loader);
+
 	free (srv);	
 	return ret_ok;
 }
@@ -519,7 +422,7 @@ set_server_socket_opts (int socket)
 
 	/* Set 'close-on-exec'
 	 */
-	fcntl (socket, F_SETFD, FD_CLOEXEC);
+	CLOSE_ON_EXEC(socket);
 		
 	/* To re-bind without wait to TIME_WAIT
 	 */
@@ -540,10 +443,12 @@ set_server_socket_opts (int socket)
 	 * listening socket. This option takes an int value, with a range of 0 to
 	 * 65535.
 	 */
+#ifdef TCP_MAXSEG
 	on = 64000;
 	re = setsockopt (socket, SOL_SOCKET, TCP_MAXSEG, &on, sizeof(on));
 	if (re != 0) return ret_error;
-	
+#endif	
+
 	/* SO_LINGER
 	 * kernels that map pages for IO end up failing if the pipe is full
          * at exit and we take away the final buffer.  this is really a kernel
@@ -717,12 +622,14 @@ print_banner (cherokee_server_t *srv)
 		cherokee_buffer_add_va (n, ", %d fds in each", srv->system_fd_limit / (srv->thread_num));	
 
 		switch (srv->thread_policy) {
+#ifdef HAVE_PTHREAD
 		case SCHED_FIFO:
 			cherokee_buffer_add (n, ", FIFO scheduling policy", 24);
 			break;
 		case SCHED_RR:
 			cherokee_buffer_add (n, ", RR scheduling policy", 22);
 			break;
+#endif
 		default:
 			cherokee_buffer_add (n, ", standard scheduling policy", 28);
 			break;
@@ -772,12 +679,17 @@ initialize_server_socket (cherokee_server_t *srv, unsigned short port, int *srv_
 
 	/* Set no-delay mode
 	 */
+#ifdef _WIN32
+	flags = 1;
+	ret = ioctlsocket (srv_socket, FIONBIO, (u_long)&flags);
+#else
 	flags = fcntl (srv_socket, F_GETFL, 0);
 	return_if_fail (flags != -1, ret_error);
 	
 	ret = fcntl (srv_socket, F_SETFL, flags | O_NDELAY);
 	return_if_fail (ret >= 0, ret_error);
-	
+#endif	
+
 	/* Listen
 	 */
 	ret = listen (srv_socket, srv->listen_queue);
@@ -868,9 +780,9 @@ while_vserver_check_tls_func (const char *key, void *value, void *param)
 static ret_t
 init_vservers_tls (cherokee_server_t *srv)
 {
+#ifdef HAVE_TLS
 	ret_t ret;
 
-#ifdef HAVE_TLS
 	/* Initialize the server TLS socket
 	 */
 	if (srv->socket_tls == -1) {
@@ -935,17 +847,13 @@ build_server_string (cherokee_server_t *srv)
 
 	/* Cherokee/x.y
 	 */
-	cherokee_buffer_add (srv->server_string, 
-			     "/"PACKAGE_MAJOR_VERSION"."PACKAGE_MINOR_VERSION,
-			     2 + PACKAGE_MAJOR_VERSION_LEN + PACKAGE_MINOR_VERSION_LEN);
+	cherokee_buffer_add_va (srv->server_string, "/%s.%s", PACKAGE_MAJOR_VERSION, PACKAGE_MINOR_VERSION);
 	if (srv->server_token <= cherokee_version_minor) 
 		return;
 
 	/* Cherokee/x.y.z-betaXX
 	 */
-	cherokee_buffer_add (srv->server_string, 
-			     "."PACKAGE_MICRO_VERSION PACKAGE_PATCH_VERSION,
-			     1 + PACKAGE_MICRO_VERSION_LEN + PACKAGE_PATCH_VERSION_LEN);
+	cherokee_buffer_add_va (srv->server_string, ".%s", PACKAGE_MICRO_VERSION PACKAGE_PATCH_VERSION);
 	if (srv->server_token <= cherokee_version_minimal) 
 		return;
 
@@ -1085,18 +993,47 @@ flush_logs (cherokee_server_t *srv)
 	cherokee_table_foreach (srv->vservers_ref, flush_vserver);
 }
 
+static ret_t
+destroy_all_threads (cherokee_server_t *srv)
+{
+	list_t *i, *tmp;
+
+	/* Set the exit flag, and try to ensure the threads are not
+	 * locked on a semaphore
+	 */
+	list_for_each_safe (i, tmp, &srv->thread_list) {
+		THREAD(i)->exit = true;
+		CHEROKEE_MUTEX_UNLOCK (&srv->accept_mutex);
+#ifdef HAVE_TLS
+		CHEROKEE_MUTEX_UNLOCK (&srv->accept_tls_mutex);
+#endif
+	} 
+
+	/* Let's destroy the threads
+	 */
+	list_for_each_safe (i, tmp, &srv->thread_list) {
+		cherokee_thread_t *thread = THREAD(i);
+
+		cherokee_thread_wait_end (thread);
+		cherokee_thread_free (thread);
+	}
+
+	return ret_ok;
+}
+
 ret_t 
 cherokee_server_reinit (cherokee_server_t *srv)
 {
-	ret_t  ret;
-	
+	ret_t                        ret;
+	cherokee_server_t           *new_srv   = NULL;
+	cherokee_server_reinit_cb_t  reinit_cb = NULL; 
+
 	if (srv->chrooted) {
 		PRINT_ERROR_S ("WARNING: Chrooted cherokee cannot be reloaded. "
 			       "Please, stop and restart it again.\n");
 		return ret_ok;
 	}
 
-
 #if 0
 	{
 		int tmp;
@@ -1105,20 +1042,31 @@ cherokee_server_reinit (cherokee_server_t *srv)
 	}
 #endif
 
-	ret = cherokee_server_clean (srv);
-	if (ret != ret_ok) {
-		exit(EXIT_SERVER_CLEAN);
-	}
+	reinit_cb = srv->reinit_callback;
 
-	// FIXME: !!!
-//	ret = read_default_config_files (srv, NULL);
-//	if (ret != ret_ok) {
-//		exit(EXIT_SERVER_READ_CONFIG);
-//	}
+	/* Close all connections
+	 */
+	close_all_connections (srv);
 
-	ret = cherokee_server_init (srv);
-	if (ret != ret_ok) {
-		exit(EXIT_SERVER_INIT);	
+	/* Destroy all the threads
+	 */
+	destroy_all_threads (srv);
+
+	/* Destroy the server object
+	 */
+	ret = cherokee_server_free (srv);
+	if (ret != ret_ok) return ret;
+	srv = NULL;
+
+	/* Create a new one
+	 */
+	ret = cherokee_server_new (&new_srv);
+	if (ret != ret_ok) return ret;
+
+	/* Send event
+	 */
+	if ((reinit_cb != NULL) && (new_srv != NULL)) {
+		reinit_cb (new_srv);
 	}
 
 	return ret_ok;
@@ -1206,8 +1154,6 @@ cherokee_server_step (cherokee_server_t *srv)
 	 */
 	if (srv->wanna_exit) {
 		cherokee_server_reinit (srv);
-		srv->wanna_exit = 0;
-		printf ("Cherokee reloaded\n");
 	}
 }
 
@@ -1223,12 +1169,12 @@ config_module_execute_function (cherokee_server_t *srv, char *param, char *func_
 
 	/* Load the module
 	 */
-	ret = cherokee_module_loader_load_no_global (srv->loader, "read_config");
+	ret = cherokee_module_loader_load_no_global (&srv->loader, "read_config");
 	if (ret != ret_ok) return ret_error;
 
 	/* Get the function
 	 */
-	ret = cherokee_module_loader_get_sym (srv->loader, "read_config", 
+	ret = cherokee_module_loader_get_sym (&srv->loader, "read_config", 
 					      func_name,
 					      (void **)&read_config);
 	if (ret != ret_ok) return ret;
@@ -1239,7 +1185,7 @@ config_module_execute_function (cherokee_server_t *srv, char *param, char *func_
 
 	/* Clean up
 	 */
-	cherokee_module_loader_unload (srv->loader, "read_config");
+	cherokee_module_loader_unload (&srv->loader, "read_config");
 
 	return ret;
 #endif
@@ -1263,6 +1209,7 @@ cherokee_server_read_config_string (cherokee_server_t *srv, char *config_string)
 ret_t 
 cherokee_server_daemonize (cherokee_server_t *srv)
 {
+#ifndef _WIN32
         pid_t child_pid;
 
         switch (child_pid = fork()) {
@@ -1280,6 +1227,7 @@ cherokee_server_daemonize (cherokee_server_t *srv)
 	default:
 		exit(0);
         }
+#endif
 
 	return ret_ok;
 }
@@ -1349,9 +1297,11 @@ cherokee_server_get_total_traffic (cherokee_server_t *srv, size_t *rx, size_t *t
 
 
 ret_t 
-cherokee_server_handle_HUP (cherokee_server_t *srv)
+cherokee_server_handle_HUP (cherokee_server_t *srv, cherokee_server_reinit_cb_t callback)
 {
-	srv->wanna_exit = 1;
+	srv->reinit_callback = callback;
+	srv->wanna_exit      = true;
+
 	return ret_ok;
 }
 
@@ -1373,7 +1323,12 @@ cherokee_server_handle_panic (cherokee_server_t *srv)
 
 	re = system (cmd->buf);
 	if (re < 0) {
-		PRINT_ERROR ("PANIC: re-panic: '%s', status %d\n", cmd->buf, WEXITSTATUS(re));
+#ifdef WEXITSTATUS		
+		int val = WEXITSTATUS(re);
+#else
+		int val = re;			
+#endif
+		PRINT_ERROR ("PANIC: re-panic: '%s', status %d\n", cmd->buf, val);
 	}
 
 	cherokee_buffer_free (cmd);
