@@ -229,9 +229,8 @@ db_store (void *ptr, gnutls_datum key, gnutls_datum data)
 static ret_t
 initialize_tls_session (cherokee_socket_t *socket, cherokee_virtual_server_t *vserver)
 {
-	int re;
-
 #ifdef HAVE_TLS
+	int re;
 
 	/* Set the virtual server object reference
 	 */
@@ -402,6 +401,7 @@ cherokee_socket_close (cherokee_socket_t *socket)
 #ifdef HAVE_GNUTLS
 		gnutls_bye (socket->session, GNUTLS_SHUT_WR);
 		gnutls_deinit (socket->session);
+		socket->session = NULL;
 #endif
 
 #ifdef HAVE_OPENSSL
@@ -409,7 +409,11 @@ cherokee_socket_close (cherokee_socket_t *socket)
 #endif
 	}
 
+#ifdef _WIN32
+	re = closesocket (socket->socket);
+#else	
 	re = close (socket->socket);
+#endif
 
 	socket->socket = -1;
 	socket->status = socket_closed;
@@ -492,10 +496,11 @@ cherokee_socket_pton (cherokee_socket_t *socket, cherokee_buffer_t *host)
 		r = inet_pton (AF_INET6, host->buf, &SOCKET_SIN_ADDR(socket));
 	} else 
 #endif
-#ifdef HAVE_INET_PTON
+
+#if defined(HAVE_INET_PTON)
 		r = inet_pton (AF_INET, host->buf, &SOCKET_SIN_ADDR(socket));
 #else		
-	        r = inet_aton (host->buf, &SOCKET_SIN_ADDR(socket));
+  	        r = inet_aton (host->buf, &SOCKET_SIN_ADDR(socket));
 #endif
 
 	return (r > 0) ? ret_ok : ret_error;
@@ -543,7 +548,6 @@ cherokee_socket_set_sockaddr (cherokee_socket_t *socket, int fd, cherokee_sockad
 	return ret_ok;
 }
 
-
 ret_t
 cherokee_socket_accept_fd (int server_socket, int *new_fd, cherokee_sockaddr_t *sa)
 {
@@ -559,32 +563,20 @@ cherokee_socket_accept_fd (int server_socket, int *new_fd, cherokee_sockaddr_t *
 		return ret_error;
 	}		
 
-	/* <EXPERIMENTAL>
+	/* Close-on-exec
 	 */
-#ifdef _WIN32
-        WSAResetEvent (socket->hSelectEvent);
-        WSAEventSelect (new_socket, socket->hSelectEvent, FD_READ | FD_CLOSE);
-#else
-	fcntl (new_socket, F_SETFD, FD_CLOEXEC);  /* close-on-exec */
-#endif
+	CLOSE_ON_EXEC (new_socket);
 	
 	/* Disable Nagle's algorithm for this connection.
 	 * Written data to the network is not buffered pending
 	 * acknowledgement of previously written data.
 	 */
  	setsockopt (new_socket, IPPROTO_TCP, TCP_NODELAY, (const void *)&tmp, sizeof(tmp));
-
-	/*  </EXPERIMENTAL>
-	 */
 	
 	/* Enables nonblocking I/O.
 	 */
-	tmp = ioctl (new_socket, FIONBIO, &tmp);
-	if (tmp < 0) {
-		PRINT_ERROR ("ERROR: Setting 'FIONBIO' in socked fd=%d\n", new_socket);
-		return ret_error;
-	}
-
+	cherokee_fd_set_nonblocking (new_socket);
+	
 	*new_fd = new_socket;
 	return ret_ok;
 }
@@ -598,7 +590,7 @@ cherokee_socket_set_client (cherokee_socket_t *sock, int type)
 		return ret_error;
 	}
 	
-	SOCKET_AF(sock) = AF_INET;
+	SOCKET_AF(sock) = type;
 
 	return ret_ok;
 }
@@ -640,7 +632,7 @@ cherokee_write (cherokee_socket_t *socket, const char *buf, int buf_len, size_t
 			}
 
 			PRINT_ERROR ("ERROR: GNUTLS: gnutls_record_send(%d, ..) -> err=%d '%s'\n", 
-				     SOCKET_FD(socket), len, gnutls_strerror(len));
+				     SOCKET_FD(socket), (int)len, gnutls_strerror(len));
 
 			*written = 0;
 			return ret_error;
@@ -676,15 +668,14 @@ cherokee_write (cherokee_socket_t *socket, const char *buf, int buf_len, size_t
 		goto out;
 	}
 
-
-#ifdef _WIN32
 	len = send (SOCKET_FD(socket), buf, buf_len, 0);
-#else 	
-	len = write (SOCKET_FD(socket), buf, buf_len);
-#endif
-
 	if (len < 0) {
-		switch (errno) {
+		int err = SOCK_ERRNO();
+
+		switch (err) {
+#if defined(EWOULDBLOCK) && (EWOULDBLOCK != EAGAIN)
+		case EWOULDBLOCK:
+#endif	
 		case EAGAIN:      
 		case EINTR:       
 			return ret_eagain;
@@ -695,7 +686,7 @@ cherokee_write (cherokee_socket_t *socket, const char *buf, int buf_len, size_t
 		}
 	
 		PRINT_ERROR ("ERROR: write(%d, ..) -> errno=%d '%s'\n", 
-			     SOCKET_FD(socket), errno, strerror(errno));
+			     SOCKET_FD(socket), err, strerror(err));
 
 		*written = 0;
 		return ret_error;
@@ -738,7 +729,7 @@ cherokee_read (cherokee_socket_t *socket, char *buf, int buf_size, size_t *done)
 			}
 			
 			PRINT_ERROR ("ERROR: GNUTLS: gnutls_record_recv(%d, ..) -> err=%d '%s'\n", 
-				     SOCKET_FD(socket), len, gnutls_strerror(len));
+				     SOCKET_FD(socket), (int)len, gnutls_strerror(len));
 
 			*done = 0;
 			return ret_error;
@@ -776,20 +767,25 @@ cherokee_read (cherokee_socket_t *socket, char *buf, int buf_size, size_t *done)
 			return ret_eof;
 		}
 #endif
-		
 		goto out;
 	}
 
-
-		if (unlikely (buf == NULL)) {
-			char tmp[buf_size+1];
-			len = read (SOCKET_FD(socket), tmp, buf_size);
-		} else {
-			len = read (SOCKET_FD(socket), buf, buf_size);
-		}
+	/* Plain read
+	 */
+	if (unlikely (buf == NULL)) {
+		char tmp[buf_size+1];
+		len = recv (SOCKET_FD(socket), tmp, buf_size, 0);
+	} else {
+		len = recv (SOCKET_FD(socket), buf, buf_size, 0);
+	}
 
 	if (len < 0) {
-		switch (errno) {
+		int err = SOCK_ERRNO();
+
+		switch (err) {
+#if defined(EWOULDBLOCK) && (EWOULDBLOCK != EAGAIN)
+		case EWOULDBLOCK:
+#endif
 		case EINTR:      
 		case EAGAIN:    
 			return ret_eagain;
@@ -800,7 +796,7 @@ cherokee_read (cherokee_socket_t *socket, char *buf, int buf_size, size_t *done)
 		}
 
 		PRINT_ERROR ("ERROR: read(%d, ..) -> errno=%d '%s'\n", 
-			     SOCKET_FD(socket), errno, strerror(errno));
+			     SOCKET_FD(socket), err, strerror(err));
 		
 		*done = 0;
 		return ret_error;
@@ -822,16 +818,31 @@ out:
 ret_t 
 cherokee_writev (cherokee_socket_t *socket, const struct iovec *vector, uint16_t vector_len, size_t *written)
 {
-#ifdef _WIN32
-	DWORD re;
-	WSASend (SOCKET_FD(socket), (LPWSABUF)vector, vector_len, &re, 0, NULL, NULL);
-#else
 	int re;
+
+#ifdef _WIN32
+	int i;
+	size_t total;
+	
+	for (i = 0, re = 0, total = 0; i < vector_len; i++, vector++) {
+		re = send (SOCKET_FD(socket), vector->iov_base, vector->iov_len, 0);
+		if (re < 0)
+			break;
+		total += re;
+	}
+	if (re >= 0)
+		re = total;
+#else
 	re = writev (SOCKET_FD(socket), vector, vector_len);
 #endif
 
 	if (re <= 0) {
-		switch (errno) {
+		int err = SOCK_ERRNO();
+		
+		switch (err) {
+#if defined(EWOULDBLOCK) && (EWOULDBLOCK != EAGAIN)
+		case EWOULDBLOCK:
+#endif
 		case EAGAIN:
 		case EINTR: 
 			return ret_eagain;
@@ -840,14 +851,15 @@ cherokee_writev (cherokee_socket_t *socket, const struct iovec *vector, uint16_t
 		case ECONNRESET:
 			return ret_eof;
 		}
-		
+	       
 		PRINT_ERROR ("ERROR: writev(%d, ..) -> errno=%d '%s'\n", 
-			     SOCKET_FD(socket), errno, strerror(errno));
+			     SOCKET_FD(socket), err, strerror(err));
 
+		
 		*written = 0;
 		return ret_error;
 	}
-
+	
 	*written = re;
 	return ret_ok;
 }
@@ -1033,12 +1045,19 @@ cherokee_socket_connect (cherokee_socket_t *socket)
 
 	r = connect (SOCKET_FD(socket), (struct sockaddr *) &SOCKET_ADDR(socket), sizeof(cherokee_sockaddr_t));
 	if (r < 0) {
-		switch (r) {
-		case ECONNREFUSED: return ret_deny;
-		case EAGAIN:       return ret_eagain;
+		int err = SOCK_ERRNO();
+		
+		switch (err) {
+		case ECONNREFUSED:
+			return ret_deny;
+		case EAGAIN:
+#if defined(EWOULDBLOCK) && (EWOULDBLOCK != EAGAIN)
+		case EWOULDBLOCK:
+#endif
+			return ret_eagain;
 		default:           
 #if 1
-			PRINT_ERROR ("ERROR: Can not connect: %s\n", strerror(errno));
+			PRINT_ERROR ("ERROR: Can not connect: %s\n", strerror(err));
 #endif
 			return ret_error;
 		}
@@ -1094,9 +1113,7 @@ cherokee_socket_init_client_tls (cherokee_socket_t *socket)
 	} while ((re == GNUTLS_E_AGAIN) ||
 		 (re == GNUTLS_E_INTERRUPTED));
 
-# endif
-
-# ifdef HAVE_OPENSSL
+# elif defined(HAVE_OPENSSL)
 
 	/* New context
 	 */
@@ -1161,7 +1178,11 @@ cherokee_socket_set_timeout (cherokee_socket_t *socket, cuint_t timeout)
 	/* Set the socket to blocking
 	 */
 	block = 0;
+#ifdef _WIN32
+	if (ioctlsocket (socket->socket, FIONBIO, &block) == SOCKET_ERROR)
+#else	
 	if (ioctl (socket->socket, FIONBIO, &block) < 0)
+#endif
 		return ret_error;
 
 	/* Set the send / receive timeouts
