@@ -131,6 +131,7 @@ typedef struct {
 #endif
 #ifdef HAVE_OPENSSL
 	SSL            *session;
+	SSL_CTX        *ssl_ctx;  /* Only client socket */
 #endif
 } cherokee_socket_t;
 
@@ -154,8 +155,11 @@ ret_t cherokee_socket_new           (cherokee_socket_t **socket);
 ret_t cherokee_socket_free          (cherokee_socket_t  *socket);
 ret_t cherokee_socket_clean         (cherokee_socket_t  *socket);
 
-ret_t cherokee_socket_init_tls      (cherokee_socket_t *socket, cherokee_virtual_server_t *vserver);
+ret_t cherokee_socket_init_tls        (cherokee_socket_t *socket, cherokee_virtual_server_t *vserver);
+ret_t cherokee_socket_init_client_tls (cherokee_socket_t *socket);
+
 ret_t cherokee_socket_close         (cherokee_socket_t *socket);
+ret_t cherokee_socket_shutdown      (cherokee_socket_t *socket, int how);
 ret_t cherokee_socket_accept        (cherokee_socket_t *socket, int server_socket);
 ret_t cherokee_socket_set_client    (cherokee_socket_t *socket, int type);
 
@@ -163,6 +167,7 @@ ret_t cherokee_socket_write         (cherokee_socket_t *socket, cherokee_buffer_
 ret_t cherokee_socket_read          (cherokee_socket_t *socket, cherokee_buffer_t *buf, size_t count, size_t *read);
 ret_t cherokee_socket_sendfile      (cherokee_socket_t *socket, int fd, size_t size, off_t *offset, ssize_t *sent);
 ret_t cherokee_socket_connect       (cherokee_socket_t *socket);
+ret_t cherokee_socket_set_timeout   (cherokee_socket_t *socket, cuint_t timeout);
 
 ret_t cherokee_socket_ntop          (cherokee_socket_t *socket, char *buf, size_t buf_size);
 ret_t cherokee_socket_pton          (cherokee_socket_t *socket, cherokee_buffer_t *buf);
