@@ -128,6 +128,18 @@ cherokee_thread_unlock (cherokee_thread_t *thd)
 }
 
 
+ret_t 
+cherokee_thread_wait_end (cherokee_thread_t *thd)
+{
+#ifdef HAVE_PTHREAD
+	/* Wait until the thread exits
+	 */
+	pthread_join (thd->thread, NULL);
+#endif
+	return ret_ok;	
+}
+
+
 ret_t 
 cherokee_thread_new  (cherokee_thread_t **thd, void *server, cherokee_thread_type_t type, 
 		      cherokee_poll_type_t fdpoll_type, int system_fd_num, int fd_num)
@@ -182,7 +194,7 @@ cherokee_thread_new  (cherokee_thread_t **thd, void *server, cherokee_thread_typ
 		/* Init the thread attributes
 		 */
 		pthread_attr_init (&attr);
-		pthread_attr_setdetachstate (&attr, PTHREAD_CREATE_DETACHED);
+		pthread_attr_setdetachstate (&attr, PTHREAD_CREATE_JOINABLE);
 		
 		/* Maybe set the scheduling policy
 		 */
@@ -368,7 +380,7 @@ process_polling_connections (cherokee_thread_t *thd)
 	list_for_each_safe (i, tmp, (list_t*)&thd->polling_list) {
 		conn = CONN(i);
 
-		/* May the connection was too much time w/o any work
+		/* Has it been too much without any work?
 		 */
 		if (conn->timeout < thd->bogo_now) {
 			purge_closed_polling_connection (thd, conn);
@@ -1014,12 +1026,6 @@ cherokee_thread_free (cherokee_thread_t *thd)
 //		thd->fcgi_managers = NULL;
 //	}
 
-	/* Destroy the thread
-	 */
-#ifdef HAVE_PTHREAD
-	pthread_exit (NULL);
-#endif	
-
 	free (thd);
 	return ret_ok;
 }
@@ -1443,7 +1449,8 @@ cherokee_thread_step_MULTI_THREAD (cherokee_thread_t *thd, cherokee_boolean_t do
 	/* Try to get new connections from https
 	 */
 	if (srv->tls_enabled) {
-		if ((thd->active_list_num == 0) &&
+		if ((thd->exit == false) &&
+		    (thd->active_list_num == 0) &&
 		    (thd->polling_list_num == 0) && (!dont_block)) {
 			step_MULTI_THREAD_TLS_block (thd, fdwatch_msecs, 
 						     srv->socket, &THREAD_SRV(thd)->accept_mutex, 	
@@ -1460,7 +1467,8 @@ cherokee_thread_step_MULTI_THREAD (cherokee_thread_t *thd, cherokee_boolean_t do
 
 	/* Try to get new connections from http
 	 */
-	if ((thd->active_list_num == 0) && 
+	if ((thd->exit == false) &&
+	    (thd->active_list_num == 0) && 
 	    (thd->polling_list_num == 0) && (!dont_block)) {
 		step_MULTI_THREAD_block (thd, srv->socket, &THREAD_SRV(thd)->accept_mutex, fdwatch_msecs);
 	} else {
