@@ -31,13 +31,20 @@
 
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <sys/socket.h>
 #include <unistd.h>
 
+#ifdef HAVE_SYS_SOCKET_H
+# include <sys/socket.h>
+#endif
+
 #ifdef HAVE_SYS_TIME_H
 # include <sys/time.h>
 #endif
 
+#ifdef HAVE_SYS_IOCTL_H
+# include <sys/ioctl.h>
+#endif
+
 #if defined (HAVE_SYS_RESOURCE_H)
 # include <sys/resource.h>
 #elif defined (HAVE_RESOURCE_H)
@@ -177,6 +184,7 @@ cherokee_sys_fdlimit_get (cuint_t *limit)
 ret_t
 cherokee_sys_fdlimit_set (cuint_t limit)
 {
+#ifndef _WIN32
 	int           re;
 	struct rlimit rl;
 
@@ -187,6 +195,7 @@ cherokee_sys_fdlimit_set (cuint_t limit)
 	if (re != 0) {
 		return ret_error;
 	}
+#endif
 
 	return ret_ok;
 }
@@ -319,7 +328,7 @@ cherokee_readdir (DIR *dirstream, struct dirent *entry, struct dirent **result)
 	CHEROKEE_MUTEX_LOCK (&readdir_mutex);
         
         errno = 0;        
-        ptr = readdir(dirp);
+        ptr = readdir(dirstream);
         
         if (!ptr && errno != 0)
                 ret = errno;
@@ -533,7 +542,7 @@ cherokee_gethostbyname (const char *hostname, struct in_addr *addr)
         char   tmp[GETHOSTBYNAME_R_BUF_LEN];
         
 
-#ifdef SOLARIS
+# ifdef SOLARIS
         /* Solaris 10:
          * struct hostent *gethostbyname_r
          *        (const char *, struct hostent *, char *, int, int *h_errnop);
@@ -543,7 +552,7 @@ cherokee_gethostbyname (const char *hostname, struct in_addr *addr)
         if (hp == NULL) {
                 return ret_error;
         }       
-#else
+# else
         /* Linux glibc2:
          *  int gethostbyname_r (const char *name,
          *         struct hostent *ret, char *buf, size_t buflen,
@@ -555,7 +564,7 @@ cherokee_gethostbyname (const char *hostname, struct in_addr *addr)
         if (r != 0) {
                 return ret_error;
         }
-#endif  
+# endif  
 
         /* Copy the address
          */
@@ -609,3 +618,22 @@ cherokee_tls_init (void)
 
 	return ret_ok;
 }
+
+
+ret_t 
+cherokee_fd_set_nonblocking (int fd)
+{
+	int tmp = 1;
+
+#ifdef _WIN32
+	tmp = ioctlsocket (fd, FIONBIO, (u_long)&tmp);
+#else	
+	tmp = ioctl (fd, FIONBIO, &tmp);
+#endif
+	if (tmp < 0) {
+		PRINT_ERROR ("ERROR: Setting 'FIONBIO' in socked fd=%d\n", fd);
+		return ret_error;
+	}
+
+	return ret_ok;
+}
