@@ -30,10 +30,15 @@
 #define CHEROKEE_UTIL_H
 
 #include <cherokee/common.h>
-#include <cherokee/buffer.h>
+
+#ifdef HAVE_NETINET_IN_H
+# include <netinet/in.h>
+#endif
+
 #include <time.h>
 #include <dirent.h>
-#include <netinet/in.h>
+
+#include <cherokee/buffer.h>
 
 
 CHEROKEE_BEGIN_DECLS
@@ -62,6 +67,8 @@ ret_t      cherokee_gethostbyname (const char *hostname, struct in_addr *addr);
 
 /* Misc
  */
+ret_t cherokee_fd_set_nonblocking (int fd);
+
 ret_t cherokee_sys_fdlimit_get (cuint_t *limit);
 ret_t cherokee_sys_fdlimit_set (cuint_t  limit);
 
