@@ -37,7 +37,8 @@ cherokee_module_info_t MODULE_INFO(plain) = {
 
 ret_t 
 cherokee_validator_plain_new (cherokee_validator_plain_t **plain, cherokee_table_t *properties)
-{
+{	
+	ret_t ret;
 	CHEROKEE_NEW_STRUCT(n,validator_plain);
 
 	/* Init 		
@@ -54,11 +55,9 @@ cherokee_validator_plain_new (cherokee_validator_plain_t **plain, cherokee_table
 	/* Get the properties
 	 */
 	if (properties) {
-		ret_t ret;
-			 
-		ret = cherokee_table_get (properties, "file", (void **) &n->file_ref);
+		ret = cherokee_typed_table_get_str (properties, "file", (char **)&n->file_ref);
 		if (ret < ret_ok) {
-			PRINT_ERROR_S ("plain validator needs a \"File\" property\n");
+			PRINT_MSG_S ("plain validator needs a \"File\" property\n");
 			return ret_error;
 		}
 	}
@@ -85,7 +84,7 @@ cherokee_validator_plain_check (cherokee_validator_plain_t *plain, cherokee_conn
 	char  *pass;
 	CHEROKEE_TEMP(line, 256);
 
-        if (cherokee_buffer_is_empty(conn->user)) {
+        if (cherokee_buffer_is_empty(&conn->user)) {
                 return ret_error;
         }
 
@@ -118,13 +117,13 @@ cherokee_validator_plain_check (cherokee_validator_plain_t *plain, cherokee_conn
 			 
 		/* Is this the right user? 
 		 */
-		if (strcmp (conn->user->buf, line) != 0) {
+		if (strcmp (conn->user.buf, line) != 0) {
 			continue;
 		}
 		
 		/* Check the password
 		 */
-		if (strcmp (conn->passwd->buf, pass) == 0) {
+		if (strcmp (conn->passwd.buf, pass) == 0) {
 			ret = ret_ok;
 			break;
 		}
